@@ -4,8 +4,9 @@ from pydantic import computed_field, field_validator, model_validator
 
 from .base import Base, UniqueList
 from .basis_set import BasisSet
+from .compute_settings import ComputeSettings
 from .correction import Correction
-from .method import METHODS_WITH_CORRECTION, PREPACKAGED_METHODS, Method
+from .method import CORRECTABLE_NNP_METHODS, METHODS_WITH_CORRECTION, PREPACKAGED_METHODS, Method
 from .mode import Mode
 from .opt_settings import OptimizationSettings
 from .scf_settings import SCFSettings
@@ -30,6 +31,7 @@ class Settings(Base):
     scf_settings: SCFSettings = SCFSettings()
     opt_settings: OptimizationSettings = OptimizationSettings()
     thermochem_settings: ThermochemistrySettings = ThermochemistrySettings()
+    compute_settings: ComputeSettings = ComputeSettings()
 
     # mypy has this dead wrong (https://docs.pydantic.dev/2.0/usage/computed_fields/)
     # Python 3.12 narrows the reason for the ignore to prop-decorator
@@ -38,12 +40,14 @@ class Settings(Base):
     def level_of_theory(self) -> str:
         corrections = list(filter(lambda x: x not in (None, ""), self.corrections))
 
-        if self.method in PREPACKAGED_METHODS or self.basis_set is None:
+        if self.method in CORRECTABLE_NNP_METHODS:
+            method = self.method.value if not corrections else f"{self.method.value}-{'-'.join(c.value for c in corrections)}"
+        elif self.method in PREPACKAGED_METHODS or self.basis_set is None:
             method = self.method.value
-        elif self.method in METHODS_WITH_CORRECTION or len(corrections) == 0:
+        elif self.method in METHODS_WITH_CORRECTION or not corrections:
             method = f"{self.method.value}/{self.basis_set.name.lower()}"
         else:
-            method = f"{self.method.value}-{'-'.join([c.value for c in corrections])}/{self.basis_set.name.lower()}"
+            method = f"{self.method.value}-{'-'.join(c.value for c in corrections)}/{self.basis_set.name.lower()}"
 
         if self.solvent_settings is not None:
             method += f"/{self.solvent_settings.model.value}({self.solvent_settings.solvent.value})"
